@@ -7,8 +7,11 @@ class PqResultSource;
 
 class PqDataFrame : public DbDataFrame {
 public:
-  PqDataFrame(PqResultSource* result_source, const std::vector<std::string>& names, const int n_max_,
-              const std::vector<DATA_TYPE>& types);
+  PqDataFrame(PqResultSource* result_source,
+              const std::vector<std::string>& names,
+              const int n_max_,
+              const std::vector<DATA_TYPE>& types,
+              std::vector<Oid> oids);
   ~PqDataFrame();
 };
 
